NOCOLOR='\033[0m'
RED='\033[0;31m'
GREEN='\033[0;32m'
ORANGE='\033[0;33m'
PURPLE='\033[0;35m'

function run_timed_command() {
  local cmd="${1}"
  local start=$(date +%s)
  echo_success "\$ ${cmd}"
  eval "${cmd}"
  local ret=$?
  local end=$(date +%s)
  local runtime=$((end-start))

  if [[ $ret -eq 0 ]]; then
    echo_success "==> '${cmd}' succeeded in ${runtime} seconds."
    return 0
  else
    echo_err "==> '${cmd}' failed (${ret}) in ${runtime} seconds."
    exit 1
  fi
}

function echo_success() {
  local header="${2}"

  if [ -n "${header}" ]; then
    printf "\n${GREEN}** %s **\n${NOCOLOR}" "${1}" >&2;
  else
    printf "${GREEN}%s\n${NOCOLOR}" "${1}" >&2;
  fi
}

function echo_err() {
  local header="${2}"

  if [ -n "${header}" ]; then
    printf "\n${RED}** %s **\n${NOCOLOR}" "${1}" >&2;
  else
    printf "${RED}%s\n${NOCOLOR}" "${1}" >&2;
  fi
}

function is_clean_deploy() {
  [ "$CLEAN_DEPLOY" = "true" ]

  local result=$?
  return $result
}

function is_test_deploy() {
  [ "$TEST_DEPLOY" = "true" ]

  local result=$?
  return $result
}

function is_local() {
    [ ! -z $CI_MERGE_REQUEST_IID ]
    
    local result=$?
    return $result
}

function is_lab() {
    [ "$CI_COMMIT_REF_NAME" = "master" ] && \
    [ "$ENV" == "lab" ] && \
    [ $SUCCESSFUL_PIPELINE_NUMBER ] 

    local result=$?
    return $result
}

function is_production() {
    [ "$ENV" == "production" ] && \
    [ $SUCCESSFUL_PIPELINE_NUMBER ] && \
    [ $TAG ]

    local result=$?
    return $result
}

function is_nightly() {
    [ "$CI_PIPELINE_SOURCE" = "schedule" ] && \
    [ "$FREQUENCY" = "nightly" ]

    local result=$?
    return $result
}

function push_international() {
    [ "$PUSH_INTERNATIONAL" = "true" ] && \
    [ $IMAGE_INTERNATIONAL ]

    local result=$?
    return $result
}

function get_environment() {
  if is_local || is_clean_deploy || is_test_deploy || is_nightly; then
    echo "local"

  elif is_lab; then
    echo "lab"

  elif is_production; then
    echo "production"

  fi
}

function docker_login() {
    echo -e "${PURPLE}Docker login...${NOCOLOR}\n"
    docker login -u $SOKAN_REGISTRY_USER \
                 -p $SOKAN_REGISTRY_PASSWORD $SOKAN_REGISTRY
    if push_international; then
      docker login -u $MARKIGHT_REGISTRY_USER \
                   -p $MARKIGHT_REGISTRY_PASSWORD $MARKIGHT_REGISTRY
    fi
}

function change_tag() {
    local source_image="${1}"
    local target_image="${2}"

    echo -e "${PURPLE}Changing Tag ${source_image} to ${target_image}...${NOCOLOR}\n"
    docker pull $source_image
    docker image tag $source_image \
                     $target_image
    docker image rm -f $source_image
}

function push() {
    local image="${1}"
    
    echo -e "${PURPLE}Pushing ${image}...${NOCOLOR}\n"
    docker push $image
}
